NoteAttachmentModel class

Inheritance

Constructors

NoteAttachmentModel(Map<String, dynamic> payload)

Properties

accessKey → String?
Attachment access key.
no setterinherited
attachType → String
Attachment type.
finalinherited
commentsCount → int?
The number of comments.
no setter
createdAt → int?
The date the note was created in Unixtime format.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → int
Attachment ID.
no setterinherited
isCanComment → bool?
Is it possible to leave comments
no setter
ownerId → int
Attachment owner identifier.
no setterinherited
payload → Map<String, dynamic>
Payload.
finalinherited
privacyView → String?
Privacy settings for commenting on a note
no setter
readCommentsCount → int?
The number of comments read (only when requesting information about the current user's note).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
The text of the note.
no setter
textWiki → String?
Wiki link tags.
no setter
title → String?
The title of the note.
no setter
viewUrl → String?
The URL of the page to display the note.
no setter

Methods

checkBoolInProperty(String key) → bool?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited