StickerAttachmentModel class

Inheritance

Constructors

StickerAttachmentModel(Map<String, dynamic> payload)

Properties

animationUrl → String?
The URL of the sticker animation.
no setter
attachType → String
Attachment type.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
images → List<StickerAttachmentImageModel>
Sticker images (with transparent background).
no setter
imagesWithBackground → List<StickerAttachmentImageModel>
Images for the sticker (with an opaque background).
no setter
isAllowed → bool?
Whether the sticker is allowed.
no setter
payload → Map<String, dynamic>
Payload.
finalinherited
productId → int
The ID of the set.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerId → int
The sticker ID.
no setter

Methods

checkBoolInProperty(String key) → bool?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited